exceptiontools.SpannerPopulationError
=====================================

.. inheritance-diagram:: abjad.tools.exceptiontools.SpannerPopulationError.SpannerPopulationError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.SpannerPopulationError.SpannerPopulationError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.SpannerPopulationError.SpannerPopulationError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.SpannerPopulationError.SpannerPopulationError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.SpannerPopulationError.SpannerPopulationError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.SpannerPopulationError.SpannerPopulationError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.SpannerPopulationError.SpannerPopulationError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.SpannerPopulationError.SpannerPopulationError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.SpannerPopulationError.SpannerPopulationError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.SpannerPopulationError.SpannerPopulationError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
